"""ansi.py."""
from __future__ import print_function

RESET = '\x1b[0;0m'
BOLD = '\x1b[1m'
UNDERLINE = '\x1b[4m'
REVERSE = '\x1b[7m'  # reverse video

RED = '\x1b[31m'
GREEN = '\x1b[32m'
YELLOW = '\x1b[33m'
BLUE = '\x1b[34m'
MAGENTA = '\x1b[35m'
CYAN = '\x1b[36m'
